==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.contenttypes.manager/test/com/openexchange/usm/contenttypes/manager/impl/ContentTypeManagerImplTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.manager.impl;

import junit.framework.TestCase;

import com.openexchange.usm.api.contenttypes.*;
import com.openexchange.usm.contenttypes.manager.impl.ContentTypeManagerImpl;
import com.openexchange.usm.journal.SimJournal;

public class ContentTypeManagerImplTest extends TestCase {

	ContentTypeManagerImpl _manager = new ContentTypeManagerImpl();
	SimContentType _contentType = new SimContentType();

	SimJournal _journal = new SimJournal();

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		_manager.activate(_journal.getLog(ContentTypeManagerImplTest.class), null); //TODO
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	public void testAddContentTypeListener() {
		SimContentTypeListener _listener = new SimContentTypeListener();
		_manager.addContentTypeListener(_listener);
//		_manager.registerContentType(_contentType);
//		assertEquals(_contentType, _listener.getType());
//		_manager.unregisterContentType(_contentType);
//		assertEquals(null, _listener.getType());
	}

	public void testRemoveContentTypeListener() {
		SimContentTypeListener _listener = new SimContentTypeListener();
		_manager.addContentTypeListener(_listener);
		_manager.removeContentTypeListener(_listener);
//		_manager.registerContentType(_contentType);
		assertEquals(null, _listener.getType());
	}

}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.contenttypes.manager/test/com/openexchange/usm/contenttypes/manager/impl/ContentTypeManagerImplTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.manager.impl;

import junit.framework.TestCase;

import com.openexchange.usm.api.contenttypes.SimContentType;
import com.openexchange.usm.api.contenttypes.SimContentTypeListener;
import com.openexchange.usm.journal.SimJournal;

public class ContentTypeManagerImplTest extends TestCase {

	protected ContentTypeManagerImpl _manager = new ContentTypeManagerImpl();
	protected SimContentType _contentType = new SimContentType();

	protected SimJournal _journal = new SimJournal();

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		_manager.activate(_journal.getLog(ContentTypeManagerImplTest.class), null); //TODO
	}

	public void testAddContentTypeListener() {
		SimContentTypeListener listener = new SimContentTypeListener();
		_manager.addContentTypeListener(listener);
		//		_manager.registerContentType(_contentType);
		//		assertEquals(_contentType, _listener.getType());
		//		_manager.unregisterContentType(_contentType);
		//		assertEquals(null, _listener.getType());
	}

	public void testRemoveContentTypeListener() {
		SimContentTypeListener listener = new SimContentTypeListener();
		_manager.addContentTypeListener(listener);
		_manager.removeContentTypeListener(listener);
		//		_manager.registerContentType(_contentType);
		assertEquals(null, listener.getType());
	}

}
